@@ -6,6 +6,8 @@ requires qw/
   is_subset_of
   validate_input
   validate_output
+  get_input_parameters
+  get_output_parameters
   /;
 
 1;
